@@ -36,7 +36,7 @@ def check_rcfile():
     """See default.config for rcfileversion values, meanings and
     a description of how to add config variables.
     """
-    rcfileversion = 9
+    rcfileversion = 10
     if cfg.get_int("app/rcfileversion") > rcfileversion:
         cfg.drop_user_config()
         return
@@ -72,6 +72,8 @@ def check_rcfile():
         cfg.del_key("melodicinterval/lowest_tone")
         cfg.del_key("harmonicinterval/highest_tone")
         cfg.del_key("harmonicinterval/lowest_tone")
+    if cfg.get_int("app/rcfileversion") <= 9:
+        cfg.del_section("mainwin")
     cfg.set_int("app/rcfileversion", rcfileversion)
 
 class SolfegeApp(cfg.ConfigUtils):
@@ -166,8 +168,13 @@ It is also possible that the OS sound setup is incorrect.
         mpd.play_music(r"\staff\relative c'{<c,,8 cis>", 80, 58,
                cfg.get_int('config/preferred_instrument_velocity'))
     def please_help_me(self):
+        # If m_viewer == 'docviewer', then we see the welcome message, and
+        # there is no help for that.
         if self.m_ui.m_viewer != 'docviewer':
-            self.handle_href('%s-help.html' % self.m_ui.m_viewer)
+            if self.m_teachers[self.m_running_exercise].m_P.header.help:
+                self.handle_href('%s.html' % self.m_teachers[self.m_running_exercise].m_P.header.help)
+            else:
+                self.handle_href('%s.html' % self.m_ui.m_viewer)
     def _practise_lesson_id(self, lesson_id, urlobj=None):
         """
         return the module name.
@@ -188,12 +195,7 @@ It is also possible that the OS sound setup is incorrect.
         return module
     def practise_lesson_id(self, lesson_id):
         module = self._practise_lesson_id(lesson_id)
-        if not self.m_teachers[module].m_P:
-            for n in self.m_ui.box_dict[module].action_area.get_children():
-                n.set_sensitive(False)
-            return
         self.m_ui.box_dict[module].on_start_practise()
-        self.m_ui.m_history.add("solfege:/%s" % lesson_id)
         return module
     def test_lesson_id(self, lesson_id):
         self.m_test_mode = True
@@ -201,9 +203,6 @@ It is also possible that the OS sound setup is incorrect.
         self.m_ui.box_dict[module].on_start_practise()
         self.m_ui.enter_test_mode()
     def handle_href(self, href, display_docfile_set_adj=1):
-        if self.m_ui.m_viewer == 'docviewer':
-            self.m_ui.m_history.set_adj_of_current(
-                self.m_ui.box_dict['docviewer'].get_vadjustment().get_value())
         urlobj = utils.Url(href)
         if not urlobj.protocol:
             if urlobj.filename.endswith(".midi"):
@@ -219,7 +218,6 @@ It is also possible that the OS sound setup is incorrect.
                 run_external_program(self.get_string("sound/midi_player"),
                         self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd, midifilename)
             else:
-                self.m_ui.hide_help_on_current()
                 self.m_ui.display_docfile(urlobj.filename, urlobj.anchor)
         elif urlobj.protocol == 'solfege':
             self.handle_solfege_href(urlobj)
@@ -240,7 +238,6 @@ It is also possible that the OS sound setup is incorrect.
         self.m_ui.hide_help_on_current()
         if urlobj.action == 'all-lessonfiles':
             self.m_ui.display_html(self.lessonfile_manager.m_htmldoc)
-            self.m_ui.m_history.add('solfege:all-lessonfiles')
             return
         if urlobj.lessonfile:
             filepath = os.path.join(self.get_string('lessoncollections/%s' % urlobj.lessoncollection), urlobj.lessonfile)
