@@ -895,7 +895,7 @@ class LessonFileManager:
                             [self.m_uiddb[p.header['lesson_id']]]
                     self.m_uiddb[p.header['lesson_id']].append(n)
     def create_lessonfile_index(self):
-        self.m_htmldoc = """<html></head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></head><body><p>%s</p>""" % _("This page lists all the lesson files that Solfege can find. You can click on the links to start practising.")
+        self.m_htmldoc = """<html><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></head><body><p>%s</p>""" % _("This page lists all the lesson files that Solfege can find. You can click on the links to start practising.")
         d = {}
         for lesson_id, n in self.m_uiddb.items():
             if not 'module' in n['header']:
