@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-copyright = "Copyright  1999-2005 Tom Cato Amundsen <tca@gnu.org>"
+copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>, and others"
 
 import sys
 import os
@@ -315,7 +315,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             self.do_tree_editor),
           ('PractiseMenu', None, _("_Practise")),
           ('TestsMenu', None, _("_Tests")),
-          ('ViewMenu', None, _('_View')),
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
           ('HelpMenu', None, _('_Help')),
@@ -325,35 +324,17 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             lambda o: self.m_app.handle_href('index.html')),
           ('HelpAllLessonFiles', None, _('All installed _lesson files'), None,
             None, lambda o: self.m_app.handle_href('solfege:all-lessonfiles')),
-          ('HelpCopyright', None, _('_Copyright notice'), None, None,
-            lambda o: self.m_app.handle_href('copyright.html')),
           ('HelpOnline', None, _('_Mailinglists, web page etc.'), None, None,
             lambda o: self.m_app.handle_href('online-resources.html')),
           ('HelpReportingBugs', None, _('Reporting _bugs'), None, None,
             lambda o: self.m_app.handle_href('bug-reporting.html')),
           ('HelpAbout', 'gtk-about', None, None, None, self.show_about_window),
-          ('ViewZoomIn', 'gtk-zoom-in', _('Help viewer zoom in'), '<ctrl>plus', None,
-           lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in()),
-          ('ViewZoomOut', 'gtk-zoom-out', _('Help viewer zoom out'), '<ctrl>minus', None,
-           lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_out()),
-          ('ViewZoom100', 'gtk-zoom-100', _('Help viewer zoom reset'), '<ctrl>equal', None,
-           lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_reset()),
           ('ShowBugReports', None, _('See your bug reports'), None, None,
             self.show_bug_reports),
         ])
 
         self.g_ui_manager.add_ui_from_file("ui.xml")
 
-        if runtime.has_gtkhtml2():
-            self.g_ui_manager.add_ui_from_string("""\
-<menubar name='Menubar'>
- <menu action='ViewMenu'>
-      <menuitem action='ViewZoomIn'/>
-      <menuitem action='ViewZoomOut'/>
-      <menuitem action='ViewZoom100'/>
- </menu>
-</menubar>""")
-
         self.add_accel_group(self.g_ui_manager.get_accel_group())
         self.g_ui_manager.get_accel_group().connect_group(gtk.keysyms.KP_Equal,
            gtk.gdk.CONTROL_MASK, 0,
@@ -536,8 +517,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             self.g_about_window = gnome.ui.About("GNU Solfege",
                   configureoutput.VERSION_STRING,
                   copyright.decode("iso-8859-1"),
-                  _("GPL'ed ear training.") + "\n" + "http://www.solfege.org",
-                  ["Tom Cato Amundsen",
+                  """
+GNU Solfege is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.""",                  ["Tom Cato Amundsen",
                   'Oliver Vollmer %s' % _("(toolbar icons)"),
                   'Giovanni Chierico %s' % _("(some lessonfiles)"),
                   'Michael Becker %s' % _("(some lessonfiles)"),
